@@ -445,23 +445,25 @@ std::string WinMain::add_object_points(const std::string& filename, const std::s
 		C3DFVector loc(0,0,0); 
 		float radius = 0; 
 		TColor color(0,0,0,0); 
+
+		string line; 
 	
-		inf >> loc.x >> loc.y >> loc.z >> color.x >> color.y>> color.z >> radius; 
+		inf >> loc.x >> loc.y >> loc.z >> color.x >> color.y >> color.z >> radius; 
 		color /= 255.0;
 		color.a = 1.0; 
 		
 		cvdebug() << "sphere" << loc << color << radius << endl; 
 		if (inf.good())
 			points_object->add_sphere(CSphereDescr(loc,radius,color));
-		else {
-			mesg += "bougus sphere list file " + filename ;  
+		else if (!inf.eof()) {
+			mesg += "bougus sphere list file '" + filename + "'\n";  
 			delete points_object; 
 			points_object = NULL; 
 		}
 	}
 
 	if (points_object) {
-		cvdebug() << "Created a points list\n"; 
+		cvdebug() << "Created a points list\n";
 		m_glview->add_object(points_object);
 		if (visible)
 			points_object->show(); 
@@ -471,7 +473,7 @@ std::string WinMain::add_object_points(const std::string& filename, const std::s
 		cvdebug() << "Add points list done\n"; 
 		mesg += filename + " DONE\n";
 	} else {
-		mesg += "no mesh data found in " + filename + "\n";
+		mesg += "no points data found in " + filename + "\n";
 	}
 	return mesg;
 }
@@ -663,32 +665,37 @@ void WinMain::add_object_texture()
 
 	std::string mesg = "Load 3D texture image: ";
 	
-	// load the textur image
-	
-	TDrawable *xy_slice = NULL;
-	TDrawable *xz_slice = NULL;
-	TDrawable *yz_slice = NULL;
-	
-	if (load_texture_images(filename, NULL, &xy_slice, axial_slice_str, &xz_slice, coronal_slice_str, &yz_slice, saggital_slice_str)) {
-		
-		remove_object_from_list(axial_slice_str, true);
-		remove_object_from_list(coronal_slice_str, true);
-		remove_object_from_list(saggital_slice_str, true);
-		
-		m_glview->add_object(xy_slice);
-		add_object_to_list(xy_slice, xy_slice->get_classname(), xy_slice->get_name(), false);
-		m_glview->add_object(xz_slice);
-		add_object_to_list(xz_slice, xz_slice->get_classname(), xz_slice->get_name(), false);
-		m_glview->add_object(yz_slice);
-		add_object_to_list(yz_slice, yz_slice->get_classname(), yz_slice->get_name(), false);
-		mesg += filename + " DONE\n";
-	} else {
-		mesg += VIEWIT_ERROR_OPEN_FILE + filename + "\n";
+
+	auto pimage = load_image3d(filename);
+	if (! pimage) {
+		string not_found = ("No supported data found in" + filename);
+		return; 
 	}
+
+	// load the textur image
+	pimage = run_filter(*pimage, "convert:repn=ubyte");
 	
+	const C3DUBImage& lumindata = static_cast<const C3DUBImage&>(*pimage); 
+
+	TDrawable *xy_slice = new TXYGLSlice(axial_slice_str, lumindata, P3DTransformation ());
+	TDrawable *xz_slice = new TXZGLSlice(coronal_slice_str, lumindata, P3DTransformation ());
+	TDrawable *yz_slice = new TYZGLSlice(saggital_slice_str, lumindata, P3DTransformation ());
+	
+	remove_object_from_list(axial_slice_str, true);
+	remove_object_from_list(coronal_slice_str, true);
+	remove_object_from_list(saggital_slice_str, true);
+		
+	m_glview->add_object(xy_slice);
+	add_object_to_list(xy_slice, xy_slice->get_classname(), xy_slice->get_name(), false);
+	m_glview->add_object(xz_slice);
+	add_object_to_list(xz_slice, xz_slice->get_classname(), xz_slice->get_name(), false);
+	m_glview->add_object(yz_slice);
+	add_object_to_list(yz_slice, yz_slice->get_classname(), yz_slice->get_name(), false);
+	mesg += filename + " DONE\n";
+		
 	viewit_signal_handler->WinStatus_append_text().emit(mesg);
 #else 
-	std::string filename = FileSelectionDialog::create_FileSelectionDialog("Load wireframe file");
+	std::string filename = FileSelectionDialog::create_FileSelectionDialog("Load volume file");
 	if (filename.empty()) 
 		return;	
 	
