@@ -95,10 +95,8 @@ TSmarties* create_smarties_from_tensorimage(VistaIOImage image, const std::strin
 					tensor.matrix.get_eigenvalues(evals);
 					tensor.eigenvalue = evals.x;
 
-					// returns non-zero if the ev is zero or the eigenvector can not be 
-					// evaluated. In these cases ignore the value; 
-					if (tensor.matrix.get_eigenvector(evals.x, tensor.evec) == 0)  {
-						tensor.evec *= (1.0 / tensor.evec.norm());
+					if (fabs(tensor.eigenvalue) > 1e-2) {
+						tensor.evec = tensor.matrix.get_eigenvector(0) / tensor.evec.norm();
 						tensor.matrix *= 300.0;
 						PPOrder.push(tensor);
 						if (PPOrder.size() > max_smarties) 
